icalendar.timezone package
==========================

.. automodule:: icalendar.timezone
   :members:
   :show-inheritance:
   :undoc-members:

Submodules
----------

.. toctree::
   :maxdepth: 4

   icalendar.timezone.equivalent_timezone_ids
   icalendar.timezone.provider
   icalendar.timezone.pytz
   icalendar.timezone.tzid
   icalendar.timezone.tzp
   icalendar.timezone.windows_to_olson
   icalendar.timezone.zoneinfo
